@@ -29,8 +29,8 @@ import types
 
 
 __author__ = 'Jure Ziberna'
-__version__ = '0.5.0'
-__date__ = '2012-27-12'
+__version__ = '0.5.2'
+__date__ = '2012-28-12'
 __license__ = 'GNU GPL 3'
 
 
@@ -50,7 +50,9 @@ EVENT_TYPES = [
 ]
 
 
-class MessageTypeError(Exception):
+class i3Exception(Exception): pass
+
+class MessageTypeError(i3Exception):
     """
     Raised when message type isn't available. See i3.MSG_TYPES.
     """
@@ -66,7 +68,7 @@ class EventTypeError(MessageTypeError):
     def __str__(self):
         return 'Event type "%s" isn\'t available' % self.type
 
-class MessageError(Exception):
+class MessageError(i3Exception):
     """
     Raised when a message to i3 is unsuccessful.
     That is, when it contains 'success': false in its JSON formatted response.
@@ -77,6 +79,15 @@ class MessageError(Exception):
             return cls(response['error'])
         return None
 
+class ConnectionError(i3Exception):
+    """
+    Raised when a socket couldn't connect to the window manager.
+    """
+    def __init__(self, socket_path):
+        self.socket_path = socket_path
+    def __str__(self):
+        return "Could not connect to socket at '%s'" % self.socket_path
+
 
 def parse_msg_type(msg_type):
     """
@@ -159,7 +170,14 @@ class Socket(object):
         """
         if not self.connected:
             self.initialize()
-            self.socket.connect(path if path else self.path)
+            if not path:
+                path = self.path
+            try:
+                self.socket.connect(path)
+            except socks.error:
+                self.socket = None
+            if not self.socket:
+                raise ConnectionError(path)
     
     def get(self, msg_type, payload=''):
         """
